"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var idioma_1 = require("../..//shared/data/idioma");
var peticion_cita_1 = require("../../common/data/peticion-cita");
var seccion_texto_1 = require("../../common/data/seccion-texto");
var resumen_cita_1 = require("../../common/data/resumen-cita");
/** Clase abstracta que define el comportamiento base de un paso de una reserva de cita. */
var ReservarCitaPaso = /** @class */ (function () {
    /** Constructor. */
    function ReservarCitaPaso(pasoNombre, campanyaService) {
        this.pasoNombre = pasoNombre;
        this.campanyaService = campanyaService;
        this.existePasoAnterior = true;
        this.visible = true; // Indica si el paso es visible en un momento dado
        this.pasoAnterior = new core_1.EventEmitter();
        this.pasoSiguiente = new core_1.EventEmitter();
        console.log(this.pasoNombre + " construido");
    }
    /** Inicialización del componente. */
    ReservarCitaPaso.prototype.ngOnInit = function () {
        this.loadDatosInicio();
        this.esCatalanSeleccionado = idioma_1.Idioma.esCatalanSeleccionado();
        console.log(this.pasoNombre + " iniciado");
    };
    /** Se activa con el cambio del input "visible", por lo que solo ejecutamos refreshDatosVisible() cuando el usuario vuelve al paso. */
    ReservarCitaPaso.prototype.ngOnChanges = function (changes) {
        if (this.visible) {
            this.refreshDatosVisible();
        }
    };
    /** Carga de datos iniciales (desde ngOnInit()). */
    ReservarCitaPaso.prototype.loadDatosInicio = function () { };
    /** Refresco de datos al volver al paso (desde otro paso). */
    ReservarCitaPaso.prototype.refreshDatosVisible = function () { };
    /** Validación del paso para poder continuar al siguiente. */
    ReservarCitaPaso.prototype.validarPaso = function () {
        return true;
    };
    /** Actualización de la información general de la reserva de cita (petición, resumen). */
    ReservarCitaPaso.prototype.updateReservaCita = function () { };
    /** Navegación al paso anterior. */
    ReservarCitaPaso.prototype.goToPasoAnterior = function () {
        this.pasoAnterior.emit();
    };
    /** Navegación al paso siguiente. */
    ReservarCitaPaso.prototype.goToPasoSiguiente = function () {
        this.updateReservaCita();
        if (this.validarPaso()) {
            this.pasoSiguiente.emit();
        }
    };
    /** Receptor del reset general. */
    ReservarCitaPaso.prototype.reset = function () {
        console.log(this.pasoNombre + " reset");
        window.scrollTo(0, 0);
        this.resetActions();
    };
    /** Acciones correspondientes al paso cuando ocurre un reset general. */
    ReservarCitaPaso.prototype.resetActions = function () { };
    Object.defineProperty(ReservarCitaPaso.prototype, "textoServicioSeleccion", {
        /** GETTERS TEXTOS DINÁMICOS */
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.SERVICIO_SELECCION, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ReservarCitaPaso.prototype, "textoServicioQueNecesito", {
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.SERVICIO_QUE_NECESITO, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ReservarCitaPaso.prototype, "textoOficinaSeleccion", {
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.OFICINA_SELECCION, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ReservarCitaPaso.prototype, "textoDatosPersonales", {
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.DATOS_PERSONALES, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ReservarCitaPaso.prototype, "textoDatosPersonalesLOPD", {
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.DATOS_PERSONALES_LOPD, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ReservarCitaPaso.prototype, "textoCitaSeleccion", {
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.CITA_SELECCION, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ReservarCitaPaso.prototype, "textoResumenCita", {
        get: function () {
            return this.campanyaService.getTexto(seccion_texto_1.SeccionTexto.CITA_RESULTADO, peticion_cita_1.PeticionCita.getServicioIds(this.peticion));
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        core_1.Input(),
        __metadata("design:type", peticion_cita_1.PeticionCita)
    ], ReservarCitaPaso.prototype, "peticion", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", resumen_cita_1.ResumenCita)
    ], ReservarCitaPaso.prototype, "resumen", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], ReservarCitaPaso.prototype, "existePasoAnterior", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Boolean)
    ], ReservarCitaPaso.prototype, "visible", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], ReservarCitaPaso.prototype, "pasoAnterior", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", Object)
    ], ReservarCitaPaso.prototype, "pasoSiguiente", void 0);
    return ReservarCitaPaso;
}());
exports.ReservarCitaPaso = ReservarCitaPaso;
//# sourceMappingURL=reservar-cita-paso.js.map